@@ -31,6 +31,7 @@ if not os.environ.get('PARSONS_SKIP_IMPORT_ALL'):
     from parsons.geocode.census_geocoder import CensusGeocoder
     from parsons.airtable.airtable import Airtable
     from parsons.copper.copper import Copper
+    from parsons.controlshift.controlshift import Controlshift
     from parsons.crowdtangle.crowdtangle import CrowdTangle
     from parsons.hustle.hustle import Hustle
     from parsons.twilio.twilio import Twilio
@@ -52,6 +53,7 @@ if not os.environ.get('PARSONS_SKIP_IMPORT_ALL'):
     from parsons.sisense.sisense import Sisense
     from parsons.alchemer.alchemer import SurveyGizmo, Alchemer
     from parsons.quickbase.quickbase import Quickbase
+    from parsons.actblue.actblue import ActBlue
 
     __all__ = [
         'VAN',
@@ -77,6 +79,7 @@ if not os.environ.get('PARSONS_SKIP_IMPORT_ALL'):
         'CensusGeocoder',
         'Airtable',
         'Copper',
+        'Controlshift',
         'CrowdTangle',
         'Hustle',
         'Twilio',
@@ -98,7 +101,8 @@ if not os.environ.get('PARSONS_SKIP_IMPORT_ALL'):
         'Sisense',
         'SurveyGizmo',
         'Alchemer',
-        'Quickbase'
+        'Quickbase',
+        'ActBlue'
     ]
 
 # Define the default logging config for Parsons and its submodules. For now the
