@@ -537,6 +537,32 @@ class ActionKit(object):
         return self._base_post(endpoint='mailer', exception_message='Could not create mailer',
                                **kwargs)
 
+    def copy_mailer(self, mailer_id):
+        """
+        copy a mailer
+        returns new copy of mailer which should be updatable.
+        """
+        resp = self.conn.post(self._base_endpoint('mailer', entity_id=mailer_id) + '/copy')
+        return(resp)
+
+    def update_mailing(self, mailer_id, **kwargs):
+        """
+        Update a mailing.
+
+        `Args:`
+            mailing_id: int
+                The id of the mailing to update
+            **kwargs:
+                Optional arguments and fields to pass to the client. A full list can be found
+                in the `ActionKit API Documentation <https://roboticdogs.actionkit.com/docs/\
+                manual/api/rest/actionprocessing.html>`_.
+        `Returns:`
+            ``None``
+        """
+
+        resp = self.conn.patch(self._base_endpoint('mailer', mailer_id), data=json.dumps(kwargs))
+        logger.info(f'{resp.status_code}: {mailer_id}')
+
     def rebuild_mailer(self, mailing_id):
         """
         Rebuild a mailer.
@@ -565,6 +591,25 @@ class ActionKit(object):
         return self._base_post(endpoint='mailer/' + str(mailing_id) + '/queue',
                                exception_message='Could not queue mailer')
 
+    def update_order(self, order_id, **kwargs):
+        """
+        Update an order.
+
+        `Args:`
+            order_id: int
+                The id of the order to update
+            **kwargs:
+                Optional arguments and fields to pass to the client. A full list can be found
+                in the `ActionKit API Documentation <https://roboticdogs.actionkit.com/docs/\
+                manual/api/rest/actionprocessing.html>`_.
+        `Returns:`
+            ``None``
+        """
+
+        resp = self.conn.patch(self._base_endpoint('order', order_id),
+                               data=json.dumps(kwargs))
+        logger.info(f'{resp.status_code}: {order_id}')
+
     def get_page_followup(self, page_followup_id):
         """
         Get a page followup.
@@ -649,6 +694,25 @@ class ActionKit(object):
                                data=json.dumps(kwargs))
         logger.info(f'{resp.status_code}: {survey_question_id}')
 
+    def update_transaction(self, transaction_id, **kwargs):
+        """
+        Update a transaction.
+
+        `Args:`
+            transaction_id: int
+                The id of the transaction to update
+            **kwargs:
+                Optional arguments and fields to pass to the client. A full list can be found
+                in the `ActionKit API Documentation <https://roboticdogs.actionkit.com/docs/\
+                manual/api/rest/actionprocessing.html>`_.
+        `Returns:`
+            ``None``
+        """
+
+        resp = self.conn.patch(self._base_endpoint('transaction', transaction_id),
+                               data=json.dumps(kwargs))
+        logger.info(f'{resp.status_code}: {transaction_id}')
+
     def create_generic_action(self, page, email=None, ak_id=None, **kwargs):
         """
         Post a generic action. One of ``ak_id`` or ``email`` is a required argument.
