@@ -2,13 +2,16 @@ import re
 import boto3
 from parsons.utilities import files
 import logging
+import os
 
 logger = logging.getLogger(__name__)
 
 
 class AWSConnection(object):
 
-    def __init__(self, aws_access_key_id=None, aws_secret_access_key=None):
+    def __init__(self, aws_access_key_id=None,
+                 aws_secret_access_key=None,
+                 aws_session_token=None):
 
         # Order of operations for searching for keys:
         #   1. Look for keys passed as kwargs
@@ -18,9 +21,15 @@ class AWSConnection(object):
         # why that's not working.
 
         if aws_access_key_id and aws_secret_access_key:
+            # The AWS session token isn't needed most of the time, so we'll check
+            # for the env variable here instead of requiring it to be passed
+            # whenever the aws_access_key_id and aws_secret_access_key are passed.
+            if aws_session_token is None:
+                aws_session_token = os.getenv('AWS_SESSION_TOKEN')
 
             self.session = boto3.Session(aws_access_key_id=aws_access_key_id,
-                                         aws_secret_access_key=aws_secret_access_key)
+                                         aws_secret_access_key=aws_secret_access_key,
+                                         aws_session_token=aws_session_token)
 
         else:
             self.session = boto3.Session()
@@ -37,14 +46,21 @@ class S3(object):
         aws_secret_access_key: str
             The AWS secret access key. Not required if the ``AWS_SECRET_ACCESS_KEY`` env
             variable is set.
+        aws_session_token: str
+            The AWS session token. Optional. Can also be stored in the ``AWS_SESSION_TOKEN``
+            env variable. Used for accessing S3 with temporary credentials.
     `Returns:`
         S3 class.
     """
 
-    def __init__(self, aws_access_key_id=None, aws_secret_access_key=None):
+    def __init__(self,
+                 aws_access_key_id=None,
+                 aws_secret_access_key=None,
+                 aws_session_token=None):
 
         self.aws = AWSConnection(aws_access_key_id=aws_access_key_id,
-                                 aws_secret_access_key=aws_secret_access_key)
+                                 aws_secret_access_key=aws_secret_access_key,
+                                 aws_session_token=aws_session_token)
 
         self.s3 = self.aws.session.resource('s3')
         """Boto3 API Session Resource object. Use for more advanced boto3 features."""
