@@ -9,6 +9,7 @@ import logging
 import os
 from parsons.databases.table import BaseTable
 from parsons.databases.mysql.create_table import MySQLCreateTable
+from parsons.databases.alchemy import Alchemy
 
 # Max number of rows that we query at a time, so we can avoid loading huge
 # data sets into memory.
@@ -18,7 +19,7 @@ QUERY_BATCH_SIZE = 100000
 logger = logging.getLogger(__name__)
 
 
-class MySQL(MySQLCreateTable):
+class MySQL(MySQLCreateTable, Alchemy):
     """
     Connect to a MySQL database.
 
@@ -36,6 +37,7 @@ class MySQL(MySQLCreateTable):
     """
 
     def __init__(self, host=None, username=None, password=None, db=None, port=3306):
+        super().__init__()
 
         self.username = check_env.check('MYSQL_USERNAME', username)
         self.password = check_env.check('MYSQL_PASSWORD', password)
@@ -86,7 +88,7 @@ class MySQL(MySQLCreateTable):
 
     def query(self, sql, parameters=None):
         """
-        Execute a query against the database. Will return ``None``if the query returns zero rows.
+        Execute a query against the database. Will return ``None`` if the query returns zero rows.
 
         To include python variables in your query, it is recommended to pass them as parameters,
         following the `mysql style <https://security.openstack.org/guidelines/dg_parameterize-database-queries.html>`_.
@@ -188,7 +190,7 @@ class MySQL(MySQLCreateTable):
                 logger.debug(f'Query returned {final_tbl.num_rows} rows.')
                 return final_tbl
 
-    def copy(self, tbl, table_name, if_exists='fail', chunk_size=1000):
+    def copy(self, tbl, table_name, if_exists='fail', chunk_size=1000, strict_length=True):
         """
         Copy a :ref:`parsons-table` to the database.
 
@@ -197,15 +199,21 @@ class MySQL(MySQLCreateTable):
             many MySQL Database configurations do not allow data files to be
             loaded. It results in a minor performance hit compared to `LOAD DATA`.
 
-        tbl: parsons.Table
-            A Parsons table object
-        table_name: str
-            The destination schema and table (e.g. ``my_schema.my_table``)
-        if_exists: str
-            If the table already exists, either ``fail``, ``append``, ``drop``
-            or ``truncate`` the table.
-        chunk_size: int
-            The number of rows to insert per query.
+        `Args:`
+            tbl: parsons.Table
+                A Parsons table object
+            table_name: str
+                The destination schema and table (e.g. ``my_schema.my_table``)
+            if_exists: str
+                If the table already exists, either ``fail``, ``append``, ``drop``
+                or ``truncate`` the table.
+            chunk_size: int
+                The number of rows to insert per query.
+            strict_length: bool
+                If the database table needs to be created, strict_length determines whether
+                the created table's column sizes will be sized to exactly fit the current data,
+                or if their size will be rounded up to account for future values being larger
+                then the current dataset. defaults to ``True``
         """
 
         if tbl.num_rows == 0:
@@ -216,7 +224,7 @@ class MySQL(MySQLCreateTable):
 
             # Create table if not exists
             if self._create_table_precheck(connection, table_name, if_exists):
-                sql = self.create_statement(tbl, table_name)
+                sql = self.create_statement(tbl, table_name, strict_length=strict_length)
                 self.query_with_connection(sql, connection, commit=False)
                 logger.info(f'Table {table_name} created.')
 
@@ -308,45 +316,6 @@ class MySQL(MySQLCreateTable):
             return False
 
     def table(self, table_name):
-        # Return a MySQL table object
+        # Return a BaseTable table object
 
-        return MySQLTable(self, table_name)
-
-
-class MySQLTable(BaseTable):
-    # MySQL table object.
-
-    def get_rows(self, offset=0, chunk_size=None):
-        """
-        Get rows from a table.
-        """
-
-        sql = f"SELECT * FROM {self.table}"
-
-        if chunk_size:
-            sql += f" LIMIT {chunk_size}"
-
-        if offset:
-            sql += f" ,{offset}"
-
-        return self.db.query(sql)
-
-    def get_new_rows(self, primary_key, cutoff_value, offset=0, chunk_size=None):
-        """
-        Get rows that have a greater primary key value than the one
-        provided.
-
-        It will select every value greater than the provided value.
-        """
-
-        sql = f"""
-               SELECT
-               *
-               FROM {self.table}
-               WHERE {primary_key} > {cutoff_value}
-               """
-
-        if chunk_size:
-            sql += f" LIMIT {chunk_size}, {offset};"
-
-        return self.db.query(sql)
+        return BaseTable(self, table_name)
