@@ -76,7 +76,7 @@ class People(object):
 
         .. note::
             A full list of possible values for the json, and its structure can be found
-            `here <https://developers.ngpvan.com/van-api#match-candidates>`_.
+            `here <https://docs.ngpvan.com/reference/people#peoplefind>`_.
 
         `Args:`
             match_json: dict
@@ -86,7 +86,7 @@ class People(object):
             A person dict object
         """
 
-        logger.info(f'Finding a match for json details.')
+        logger.info('Finding a match for json details.')
 
         return self._people_search(match_json=match_json)
 
@@ -150,7 +150,7 @@ class People(object):
 
         .. note::
             A full list of possible values for the json, and its structure can be found
-            `here <https://docs.ngpvan.com/reference/people#common-models>`_.
+            `here <https://docs.ngpvan.com/reference/people#peoplevanid>`_.
 
         `Args:`
             id: str
@@ -233,7 +233,7 @@ class People(object):
 
         .. note::
             A full list of possible values for the json, and its structure can be found
-            `here <https://docs.ngpvan.com/reference/people#common-models>`_. `vanId` can
+            `here <https://docs.ngpvan.com/reference/people#peoplefindorcreate>`_. `vanId` can
             be passed to ensure the correct record is updated.
 
         .. warning::
@@ -447,7 +447,7 @@ class People(object):
         to a person record. This method allows you apply multiple responses (e.g. two survey
         questions) at the same time. It is a low level method that requires that you
         conform to the VAN API `response object
-        format <https://docs.ngpvan.com/reference/people#peoplevanidcanvassresponses>`_.
+        format <https://docs.ngpvan.com/reference/canvass-responses>`_.
 
         `Args:`
             id: str
@@ -530,7 +530,7 @@ class People(object):
                 'vanId': vanid_2}
 
         self.connection.post_request(f"people/{vanid_1}/relationships", json=json)
-        logger.info('Relationship {vanid_1} to {vanid_2} created.')
+        logger.info(f'Relationship {vanid_1} to {vanid_2} created.')
 
     def apply_person_code(self, id, code_id, id_type='vanid'):
         """
