@@ -3,8 +3,8 @@ import csv
 """
 This utility method is a generalizable method for moving files to an
 online file storage class. It is used by methods that require access
-to a file via a public url (e.g. VAN). Currently only includes S3, but
-in the future, might include SFTP, and Google Cloud Storage.
+to a file via a public url (e.g. VAN). Currently only includes Amazon S3 and
+Google Cloud Storage.
 """
 
 
@@ -20,7 +20,7 @@ def post_file(tbl, type, file_path=None, quoting=csv.QUOTE_MINIMAL, **file_stora
         tbl: object
             parsons.Table
         type: str
-            ``S3``
+            ``S3`` or ``GCS`` (Google Cloud Storage)
         file_path: str
             The file path to store the file. Not required if provided with
             the **file_storage_args.
@@ -32,7 +32,7 @@ def post_file(tbl, type, file_path=None, quoting=csv.QUOTE_MINIMAL, **file_stora
         ``None``
     """
 
-    if type.capitalize() == 'S3':
+    if type.upper() == 'S3':
 
         # Overwrite the file_path if key is passed
         if 'key' in file_storage_args:
@@ -40,7 +40,11 @@ def post_file(tbl, type, file_path=None, quoting=csv.QUOTE_MINIMAL, **file_stora
 
         return tbl.to_s3_csv(public_url=True, key=file_path, quoting=quoting, **file_storage_args)
 
-    # To Do: Add in SFTP, GoogleCloud Storage
+    elif type.upper() == 'GCS':
+
+        return tbl.to_gcs_csv(public_url=True, blob_name=file_path, quoting=quoting,
+                              **file_storage_args)
 
     else:
-        raise ValueError('Type must be S3.')
+
+        raise ValueError('Type must be S3 or GCS.')
